[PATCH] board: ti: am654: Disable SA2UL node for HS devices

Andrew F. Davis afd at ti.com
Tue Jun 9 21:14:22 CEST 2020


On HS devices the access to SA2UL is restricted on the non-secure
ARM side, disable the node in DT to prevent firewall violations.
We used to only disable the TRNG but now that we have full SA2UL
support in Linux, in which TRNG is a sub-module, disable both
by disabling the parent SA2UL node.

Signed-off-by: Andrew F. Davis <afd at ti.com>
---
 board/ti/am65x/evm.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/board/ti/am65x/evm.c b/board/ti/am65x/evm.c
index a22900dcf9..20b75ba133 100644
--- a/board/ti/am65x/evm.c
+++ b/board/ti/am65x/evm.c
@@ -108,10 +108,10 @@ int ft_board_setup(void *blob, bd_t *bd)
 	}
 
 #if defined(CONFIG_TI_SECURE_DEVICE)
-	/* Make HW RNG reserved for secure world use */
-	ret = fdt_disable_node(blob, "/interconnect at 100000/trng at 4e10000");
+	/* Make Crypto HW reserved for secure world use */
+	ret = fdt_disable_node(blob, "/interconnect at 100000/crypto at 4E00000");
 	if (ret)
-		printf("%s: disabling TRGN failed %d\n", __func__, ret);
+		printf("%s: disabling SA2UL failed %d\n", __func__, ret);
 #endif
 
 	return 0;
-- 
2.17.1



More information about the U-Boot mailing list